@@ -1,15 +1,15 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Contains abstract class to hold relation preferences/statistics
- *
- * @package PhpMyAdmin
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Plugins\Schema;
 
-use PhpMyAdmin\Plugins\Schema\TableStats;
+use function abs;
+use function array_search;
+use function min;
 
 /**
  * Relations preferences/statistics
@@ -18,26 +18,35 @@ use PhpMyAdmin\Plugins\Schema\TableStats;
  * and helps in generating the Table references and then connects
  * master table's master field to foreign table's foreign key.
  *
- * @package PhpMyAdmin
  * @abstract
  */
 abstract class RelationStats
 {
+    /** @var object */
     protected $diagram;
-    /**
-     * Defines properties
-     */
+
+    /** @var mixed */
     public $xSrc;
+
+    /** @var mixed */
     public $ySrc;
+
+    /** @var int */
     public $srcDir;
+
+    /** @var int */
     public $destDir;
+
+    /** @var mixed */
     public $xDest;
+
+    /** @var mixed */
     public $yDest;
-    public $wTick;
+
+    /** @var int */
+    public $wTick = 0;
 
     /**
-     * The constructor
-     *
      * @param object $diagram       The diagram
      * @param string $master_table  The master table name
      * @param string $master_field  The relation field in the master table
@@ -53,8 +62,8 @@ abstract class RelationStats
     ) {
         $this->diagram = $diagram;
 
-        $src_pos = $this->_getXy($master_table, $master_field);
-        $dest_pos = $this->_getXy($foreign_table, $foreign_field);
+        $src_pos = $this->getXy($master_table, $master_field);
+        $dest_pos = $this->getXy($foreign_table, $foreign_field);
         /*
          * [0] is x-left
         * [1] is x-right
@@ -92,6 +101,7 @@ abstract class RelationStats
             $this->xDest = $dest_pos[1];
             $this->destDir = 1;
         }
+
         $this->ySrc = $src_pos[2];
         $this->yDest = $dest_pos[2];
     }
@@ -103,10 +113,8 @@ abstract class RelationStats
      * @param string     $column The relation column name
      *
      * @return array Arrows coordinates
-     *
-     * @access private
      */
-    private function _getXy($table, $column)
+    private function getXy($table, $column)
     {
         $pos = array_search($column, $table->fields);
 
